from setuptools import setup

setup(name='ataiat_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['ataiat_probability'],
      author = 'Ashutosh A. Patwardhan',
      author_email = 'ashutosh.patwardhan@iitbombay.org',
      zip_safe=False)
